@@ -51,116 +51,9 @@ def get_odoo_addons_paths(
         else:
             res.append(c / x)
 
-
     return res
 
 
-def _identify_odoo_addons_paths(show_conflicts=True):
-    from .module_tools import Module
-
-    folders = []
-    c = customs_dir()
-
-    modules = []
-
-    def _get_modules_in_folder(folder):
-        # find extra modules without repo
-        for file in folder.glob("**/{}".format(MANIFEST_FILE())):
-            if ".git" in file.parts:
-                continue
-            file = file.resolve().absolute()
-            if file.parent.parent in folders:
-                continue
-            if any(x in file.relative_to(c).parts for x in {"test", "tests", ".git"}):
-                continue
-            try:
-                module = Module(file)
-            except Module.IsNot:
-                continue
-            if module.in_version:
-                if module.path.parent not in folders:
-                    folders.append(module.path.parent)
-                    modules.append(module)
-            del file
-
-    manifest = MANIFEST()
-
-    oca_addons = [
-        "addons_oca",
-        "OCA",
-        "addons_OCA",
-        "*OCA",
-    ]
-    for oca in oca_addons:
-        if oca not in os.listdir(c):
-            continue
-
-        for oca_folder in list(c.glob(oca)):  # case insensitive on windows / macos
-            _get_modules_in_folder(oca_folder)
-            del oca_folder
-        del oca
-
-    for module in manifest["modules"]:
-        for url in module["urls"]:
-            repo_name = url.split("/")[-1].replace(".git", "")
-            path = c / Path(module["path"]) / repo_name
-            _get_modules_in_folder(path)
-            del url
-        del module
-
-    folders = list(reversed(folders))
-    for odoo_folder in filter(
-        lambda x: x.exists(),
-        map(
-            Path,
-            [
-                c / "odoo" / "openerp" / "addons",  # backwards compatibility
-                c / "odoo" / "addons",
-                c / "odoo" / "odoo" / "addons",
-            ],
-        ),
-    ):
-        if not odoo_folder.exists():
-            continue
-        _get_modules_in_folder(odoo_folder)
-        del odoo_folder
-    folders = list(reversed(folders))
-    _get_modules_in_folder(c)
-
-    if show_conflicts:
-        _detect_duplicate_modules(folders, modules)
-
-    return folders
-
-
-def _detect_duplicate_modules(folders, modules):
-    from .module_tools import Module
-
-    check_modules = {}
-    c = customs_dir()
-    for folder in folders:
-        folder_rel = folder.relative_to(c)
-        modules_in_folder = [
-            x for x in modules if str(x.path.relative_to(c)).startswith(str(folder_rel))
-        ]
-        for module in modules_in_folder:
-            check_modules.setdefault(module.name, [])
-            if module.path not in [x.path for x in check_modules[module.name]]:
-                check_modules[module.name].append(module)
-
-    for v in filter(lambda x: len(x) > 1, check_modules.values()):
-        click.echo(
-            click.style(
-                "Overridden Module: {}".format(v[0].name), bold=True, fg="green"
-            )
-        )
-        for i, module in enumerate(v):
-            styles = dict(bold=True) if not i else {}
-            s = str(module.path.relative_to(c))
-            click.echo(click.style(s, **styles))
-    time.sleep(2)
-
-
 def customs_dir():
     env_customs_dir = os.getenv("CUSTOMS_DIR")
     if not env_customs_dir:
